==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/autoattendant/saveAutoattendant.php <==
<?php

	require('../assets/inc/ldapConnect.php');
	$aaSave = (isset($_REQUEST['aaSave']) && strlen($_REQUEST['aaSave']) >=1 ) ? $_REQUEST['aaSave'] : NULL;
	
	$query = ($aaSave === '0') ? "cn=AutoAttendant" : "cn=AutoAttendant, cn=$aaSave, cn=Companies";
	
	if (isset($_REQUEST['one']) 	&& strlen($_REQUEST['one']) >=1) 		update('1',$_REQUEST['one']);
	if (isset($_REQUEST['two']) 	&& strlen($_REQUEST['two']) >=1) 		update('2',$_REQUEST['two']);
	if (isset($_REQUEST['three']) 	&& strlen($_REQUEST['three']) >=1) 		update('3',$_REQUEST['three']);
	if (isset($_REQUEST['four']) 	&& strlen($_REQUEST['four']) >=1) 		update('4',$_REQUEST['four']);
	if (isset($_REQUEST['five']) 	&& strlen($_REQUEST['five']) >=1) 		update('5',$_REQUEST['five']);
	if (isset($_REQUEST['six']) 	&& strlen($_REQUEST['six']) >=1) 		update('6',$_REQUEST['six']);
	if (isset($_REQUEST['seven']) 	&& strlen($_REQUEST['seven']) >=1) 		update('7',$_REQUEST['seven']);
	if (isset($_REQUEST['eight']) 	&& strlen($_REQUEST['eight']) >=1) 		update('8',$_REQUEST['eight']);
	if (isset($_REQUEST['nine']) 	&& strlen($_REQUEST['nine']) >=1) 		update('9',$_REQUEST['nine']);
	if (isset($_REQUEST['zero']) 	&& strlen($_REQUEST['zero']) >=1) 		update('0',$_REQUEST['zero']);
	if (isset($_REQUEST['star']) 	&& strlen($_REQUEST['star']) >=1) 		update('*',$_REQUEST['star']);
	if (isset($_REQUEST['hash']) 	&& strlen($_REQUEST['hash']) >=1) 		update('#',$_REQUEST['hash']);
	if (isset($_REQUEST['timeout']) && strlen($_REQUEST['timeout']) >=1) 	update('?',$_REQUEST['timeout']);
	
	function update($key, $value) {
		global $ds, $query;
		$sr = @ldap_read($ds,"cn=$key,$query","objectclass=autoattendantkey",array('cn','telephonenumber')); 
		$ent['telephonenumber'] = $value;
		$dn = "cn=$key, $query";
		
		if ($value == 'delete entry') {
			
			ldap_delete($ds, $dn);
			
		} else {
	
			if ($sr) {
				ldap_modify($ds, $dn, $ent);
			} else {
				$ent['objectclass'] = 'autoattendantkey';
				ldap_add($ds, $dn, $ent);
			}
			
		}
	}
	
	audit ("[AutoAttendant] Update");
			
?>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/autoattendant/saveAutoattendant.php <==
<?php

	require('../assets/inc/ldapConnect.php');
	$aaSave = (isset($_REQUEST['aaSave']) && strlen($_REQUEST['aaSave']) >=1 ) ? $_REQUEST['aaSave'] : NULL;
	$query = ($aaSave === '0') ? "cn=AutoAttendant" : "cn=AutoAttendant, cn=$aaSave, cn=Companies";
	
	if (isset($_REQUEST['one']) 	&& strlen($_REQUEST['one']) >=1) 		update('1',$_REQUEST['one']);
	if (isset($_REQUEST['two']) 	&& strlen($_REQUEST['two']) >=1) 		update('2',$_REQUEST['two']);
	if (isset($_REQUEST['three']) 	&& strlen($_REQUEST['three']) >=1) 		update('3',$_REQUEST['three']);
	if (isset($_REQUEST['four']) 	&& strlen($_REQUEST['four']) >=1) 		update('4',$_REQUEST['four']);
	if (isset($_REQUEST['five']) 	&& strlen($_REQUEST['five']) >=1) 		update('5',$_REQUEST['five']);
	if (isset($_REQUEST['six']) 	&& strlen($_REQUEST['six']) >=1) 		update('6',$_REQUEST['six']);
	if (isset($_REQUEST['seven']) 	&& strlen($_REQUEST['seven']) >=1) 		update('7',$_REQUEST['seven']);
	if (isset($_REQUEST['eight']) 	&& strlen($_REQUEST['eight']) >=1) 		update('8',$_REQUEST['eight']);
	if (isset($_REQUEST['nine']) 	&& strlen($_REQUEST['nine']) >=1) 		update('9',$_REQUEST['nine']);
	if (isset($_REQUEST['zero']) 	&& strlen($_REQUEST['zero']) >=1) 		update('0',$_REQUEST['zero']);
	if (isset($_REQUEST['star']) 	&& strlen($_REQUEST['star']) >=1) 		update('*',$_REQUEST['star']);
	if (isset($_REQUEST['hash']) 	&& strlen($_REQUEST['hash']) >=1) 		update('#',$_REQUEST['hash']);
	if (isset($_REQUEST['timeout']) && strlen($_REQUEST['timeout']) >=1) 	update('?',$_REQUEST['timeout']);
	
	function update($key, $value) {
		global $ds, $query;
		$timestamp = time();
		
		$sr = @ldap_read($ds,"cn=$key,$query","objectclass=autoattendantkey",array('cn','telephonenumber')); 
		$ent['telephonenumber'] = $value;
		$dn = "cn=$key, $query";
		
		if ($value == 'delete entry') {
			
			ldap_delete($ds, $dn);
			audit ($timestamp, "[AutoAttendant] [Delete] $value", $dn);
			
		} else {
	
			if ($sr) {
				ldap_modify($ds, $dn, $ent);
				audit ($timestamp, "[AutoAttendant] [Update] $value", $dn);
			} else {
				$ent['objectclass'] = 'autoattendantkey';
				ldap_add($ds, $dn, $ent);
				audit ($timestamp, "[AutoAttendant] [Add] $value", $dn);
			}
			
		}
	}
	
	
			
?>
